@@ -28,15 +28,17 @@ class OwsHandler(BaseHandler):
     """
     def initialize(self, client: AsyncClient, timeout: int, 
                    monitor: Optional[Monitor]=None, 
-                   http_proxy: bool=False) -> None:
+                   http_proxy: bool=False,
+                   allowed_hdrs: List[str]=[] ) -> None:
 
         super().initialize()
 
-        self._client      = client
-        self._timeout     = timeout
-        self._monitor     = monitor
-        self._proxy       = http_proxy
-        self._stats       = self.application.stats
+        self._client       = client
+        self._timeout      = timeout
+        self._monitor      = monitor
+        self._proxy        = http_proxy
+        self._stats        = self.application.stats
+        self._allowed_hdrs = allowed_hdrs
 
     async def handle_request(self, method: str, endpoint: Optional[str], data: Optional=None ) -> Awaitable[None]:
         reqtime = time()
@@ -54,15 +56,16 @@ class OwsHandler(BaseHandler):
             if proxy_url: 
                 headers['X-Forwarded-Url']=proxy_url
 
-            def copy_headers(pat):
-                headers.update((k,v) for k,v in self.request.headers.items() if k.upper().startswith(pat))
+            def copy_headers(pats):
+                headers.update((k,v) for k,v in self.request.headers.items() if \
+                               any(map(k.upper().startswith,pats)))
 
             # Copy custom Qgis/Forwarded headers
             # see https://github.com/qgis/QGIS/pull/41333
-            copy_headers('X-QGIS-')
+            copy_headers(self._allowed_hdrs)
 
-            if self.has_body_arguments:
-                # Do not let qgis server handle url encoded prameters
+            if self.get_argument('SERVICE', default=None) and  self.has_body_arguments:
+                # Do not let qgis server handle url encoded parameters
                 data = None
                 if method == 'POST':
                     method = 'GET'
@@ -137,7 +140,7 @@ class OwsHandler(BaseHandler):
         self.set_option_headers('GET, POST, OPTIONS')
 
 
-class OwsFilterHandler(OwsHandler):
+class _FilterHandlerMixIn:
     """ Handle filter handlers
     """
     def initialize(self, filters: Optional[List]=None, **kwargs) -> None:
@@ -152,6 +155,10 @@ class OwsFilterHandler(OwsHandler):
             await filt.apply( self )
 
 
+class OwsFilterHandler(_FilterHandlerMixIn,OwsHandler):
+    pass
+
+
 class OwsApiHandler(OwsHandler):
     """ Handle Qgis api
     """
@@ -173,3 +180,7 @@ class OwsApiHandler(OwsHandler):
     async def patch(self, endpoint: Optional[str]=None) -> Awaitable[None]:
         await self.handle_request('PATCH', endpoint)
 
+
+class OwsApiFilterHandler(_FilterHandlerMixIn, OwsApiHandler):
+    pass
+
